#ifndef NT2_INCLUDE_FUNCTIONS_REC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REC_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/rec.hpp>

#endif
